@@ -10,7 +10,7 @@ if ( preg_match('{/always.php$}', $_SERVER['SCRIPT_NAME'] ) ) header('Location:
 
 // XSS Protection
 function filter_post(&$val, $index) {
-    if(in_array($index, ["newpass1", "newpass2"])) return;
+    if(in_array($index, ["newpass1", "newpass2", "password"])) return;
 
     switch (gettype($val)) {
         case "string":
@@ -44,8 +44,12 @@ function clean_get() {
 // relies on variables that are easily manipulated by the user. These lines and functions filter all those variables.
 if(isset($_POST)) array_walk($_POST, 'filter_post');
 $_GET = clean_get();
-$_SERVER['REQUEST_URI'] = str_replace("&amp;", "&", htmlspecialchars($_SERVER['REQUEST_URI']));
-$_SERVER['HTTP_REFERER'] = htmlspecialchars(@$_SERVER['HTTP_REFERER']);
+if (isset($_SERVER['REQUEST_URI'])) {
+    $_SERVER['REQUEST_URI'] = str_replace("&amp;", "&", htmlspecialchars($_SERVER['REQUEST_URI']));
+}
+if (isset($_SERVER['HTTP_REFERER'])) {
+    $_SERVER['HTTP_REFERER'] = htmlspecialchars(@$_SERVER['HTTP_REFERER']);
+}
 
 
 
@@ -287,8 +291,8 @@ if ( function_exists('awl_set_locale') ) {
 *
 */
 $c->code_version = 0;
-$c->want_awl_version = '0.62';
-$c->version_string = '1.1.10'; // The actual version # is replaced into that during the build /release process
+$c->want_awl_version = '0.63';
+$c->version_string = '1.1.11'; // The actual version # is replaced into that during the build /release process
 if ( isset($c->version_string) && preg_match( '/(\d+)\.(\d+)\.(\d+)(.*)/', $c->version_string, $matches) ) {
   $c->code_major = $matches[1];
   $c->code_minor = $matches[2];
@@ -458,26 +462,8 @@ function DeconstructURL( $url ) {
 * @param string $isodate The date to convert
 */
 function ISODateToHTTPDate( $isodate ) {
-  // It is necessary to use English for this, explicitly.  See Debian BTS Bug#661985 for more info.
-  $month = gmstrftime('%m', strtotime($isodate));
-  switch( intval($month) ) {
-    case 1: $month = 'Jan'; break;
-    case 2: $month = 'Feb'; break;
-    case 3: $month = 'Mar'; break;
-    case 4: $month = 'Apr'; break;
-    case 5: $month = 'May'; break;
-    case 6: $month = 'Jun'; break;
-    case 7: $month = 'Jul'; break;
-    case 8: $month = 'Aug'; break;
-    case 9: $month = 'Sep'; break;
-    case 10: $month = 'Oct'; break;
-    case 11: $month = 'Nov'; break;
-    case 12: $month = 'Dec'; break;
-    default:
-      throw new Exception('Invalid month '.$month);
-  }
   // Use strtotime since strptime is not available on Windows platform.
-  return( gmstrftime('%a, %d '.$month.' %Y %H:%M:%S GMT', strtotime($isodate)) );
+  return( gmdate('D, d M Y H:i:s T', strtotime($isodate)) );
 }
 
 /**
